@@ -18,12 +18,9 @@ MIDDLEWARE = (
 )
 
 INSTALLED_APPS = [
-    'django_nose',
     'eventtracking.django'
 ]
 
-TEST_RUNNER = 'django_nose.NoseTestSuiteRunner'
-
 EVENT_TRACKING_ENABLED = True
 
 SECRET_KEY = "test_key"
